@@ -11,7 +11,7 @@ WWW::Suffit::API - The Suffit API
 
 =head1 VERSION
 
-API Version 1.00
+API Version 1.01
 
 =head1 DESCRIPTION
 
@@ -539,6 +539,73 @@ Get RSA public key of user (the token issuer)
       "status": true
     }
 
+=head2 POST /authorize
+
+This method performs authentication and authorization on the Suffit API server,
+then returns the access token
+
+    # curl -v -X POST \
+      -H "Accept: application/json" \
+      -d '{
+        "username": "test",
+        "password": "test",
+        "encrypted": false
+      }' \
+      https://localhost:8695/authorize
+
+    # curl -v -X POST \
+      -H "Accept: application/json" \
+      -F username=test -F password=test \
+      https://localhost:8695/authorize
+
+    > POST /authorize HTTP/1.1
+    > Host: localhost:8695
+    > User-Agent: curl/7.68.0
+    > Accept: application/json
+    > Content-Length: 248
+    > Content-Type: multipart/form-data; boundary=-----6a21ca7cea8dc981
+    >
+    < HTTP/1.1 200 OK
+    < Date: Thu, 11 May 2023 14:30:34 GMT
+    < Content-Type: application/json;charset=UTF-8
+    < Content-Length: 635
+    < Server: WWW::Suffit/1.00
+    <
+    {
+      "clientid": "f459f12619c961122450ae5883e44a60",
+      "code": "E0000",
+      "datetime": "2023-12-17T07:47:56Z",
+      "elapsed": 0.313583,
+      "encrypted": false,
+      "expires": "2023-12-18T07:47:56Z",
+      "jti": "kB...hO",
+      "message": "The user is successfully authorized",
+      "referer": "",
+      "status": true,
+      "token": "ey...1o",
+      "type": "access",
+      "user": {
+        "algorithm": "SHA256",
+        "attributes": "",
+        "comment": "Test user for internal testing only",
+        "created": 1678741533,
+        "email": "test@localhost",
+        "email_md5": "163e50783979333ebae6fd63b2d96d16",
+        "expires": 1702799576,
+        "flags": 31,
+        "groups": [
+          "user"
+        ],
+        "name": "Test User",
+        "not_after": 0,
+        "not_before": 1695334721,
+        "public_key": "-----BEGIN RSA PUBLIC KEY-----...",
+        "role": "Test user",
+        "uid": 3,
+        "username": "test"
+      }
+    }
+
 =head2 ERROR CODES
 
 =over 8
@@ -864,7 +931,7 @@ See C<LICENSE> file and L<https://dev.perl.org/licenses/>
 
 =cut
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 1;
 
